@@ -25,6 +25,9 @@
 
 #include "control-data.h"
 
-gint   popup_show      (GtkHTMLControlData *cd, GdkEventButton *event);
+gint  popup_show            (GtkHTMLControlData *cd,
+			     GdkEventButton     *event);
+gint  popup_show_at_cursor  (GtkHTMLControlData *cd);
+void  property_dialog_show  (GtkHTMLControlData *cd);
 
 #endif
