@@ -22,7 +22,11 @@
 */
 
 #include <config.h>
-#include <libgnome/gnome-i18n.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
+#include <glib/gi18n.h>
+#endif
 
 #include <gnome.h>
 #include <bonobo.h>
